function imgtolvl(file, key)
    local lvl = {}
    local lvltxt = ''
    local img = love.image.newImageData(file)
    for y=1, img:getHeight(), 1 do
        for x=1, img:getWidth(), 1 do
            local r, g, b, a = img:getPixel(x-1, y-1)
            for c=1, #key, 1 do
                if key[c][1] == r..'.'..g..'.'..b then
                    lvltxt = lvltxt..key[c][2]
                end
            end
        end
    end
    table.insert(lvl, img:getWidth())
    table.insert(lvl, img:getHeight())
    table.insert(lvl, file)
    table.insert(lvl, lvltxt)
    return lvl
end

function loadlevel(lvl) 
	blocknum = 0
	for block in string.gmatch(lvl[4], ".") do
		if block == "w" then
			objects.new("platform", math.floor(blocknum%lvl[1])*21+(21/2), math.floor(blocknum/lvl[2])*21+(21/2), 21, 21, 3, imgground, "static")
		elseif block == "b" then
			objects.new("box", math.floor(blocknum%lvl[1])*21+(21/2), math.floor(blocknum/lvl[2])*21+(21/2), 21, 21, 3, imgbox, "dynamic")
		end
		blocknum = blocknum + 1
	end
end


function love.load()
    pxm = 32
    love.physics.setMeter(pxm)
    world = love.physics.newWorld(0, 9.81*pxm)

	objects = {
		box = {
			all = {}
		},
		platform = {
			all = {}
		},
		player = {
			all = {},
			init = function(body)
				body:setFixedRotation(true)
			end
		},
		new = function(objtype, x, y, w, h, d, i, bodytype)  -- Object type, x position, y position, width, height, density, image
			objects[objtype].all[#objects[objtype].all+1] = {}
		    objects[objtype].all[#objects[objtype].all].body = love.physics.newBody(world, x, y, bodytype)
			objects[objtype].all[#objects[objtype].all].shape = love.physics.newRectangleShape(0, 0, w, h)
			objects[objtype].all[#objects[objtype].all].fixture = love.physics.newFixture(objects[objtype].all[#objects[objtype].all].body, objects[objtype].all[#objects[objtype].all].shape, d)
			objects[objtype].all[#objects[objtype].all].image = i
			objects[objtype].all[#objects[objtype].all].width = w
			objects[objtype].all[#objects[objtype].all].height = h
			if objects[objtype].init ~= nil then objects[objtype].init(objects[objtype].all[#objects[objtype].all].body) end
		end
	}

	imgbox = love.graphics.newImage("img/box1.png")
	imgbg = love.graphics.newImage("img/background1.png")
	imgplayer = love.graphics.newImage("img/player1/1.png")
	imgground = love.graphics.newImage("img/ground1.png")
	
	--objects.new("box", 200, 550, 21, 21, 3, imgbox, "dynamic")
	objects.new("player", 700/2, 700/2, 17, 21, 1, imgplayer, "dynamic")
	--objects.new("platform", 700/2, 700-100/2, 700, 100, 1, imgbg, "static")
	--objects.new("platform", 0, 700/2, 100, 700, 1, imgbg, "static")
	--objects.new("platform", 700, 700/2, 100, 700, 1, imgbg, "static")
	
	key = {
		{'0.0.0', 'w'},
		{'255.255.255', 'a'},
		{'153.69.49', 'b'},
		{'69.64.179', 'p'},
	}
	
	loadlevel(imgtolvl("lvl/test.png", key))
end


function love.update(dt)
    world:update(dt)
	
	if love.mouse.isDown("l") then
		objects.new("box", love.mouse.getX(), love.mouse.getY(), 21, 21, 3, imgbox, "dynamic")
	end
 
    if love.keyboard.isDown("right") then
        objects.player.all[1].body:applyForce(400, 0)
    elseif love.keyboard.isDown("left") then
        objects.player.all[1].body:applyForce(-400, 0)
    elseif love.keyboard.isDown("r") then
        objects.player.all[1].body:setPosition(650/2, 650/2)
	elseif love.keyboard.isDown("up") then
		objects.player.all[1].body:applyLinearImpulse(0, -10)
    end
end



function love.draw()
	love.graphics.draw(imgbg, 0, 0)

	for obj,objkey in pairs(objects) do
		if type(objkey) == "table" then
			for objnum=1,#objkey.all,1 do
				love.graphics.draw(objkey.all[objnum].image, objkey.all[objnum].body:getX(), objkey.all[objnum].body:getY(), objkey.all[objnum].body:getAngle(), 1, 1, objkey.all[objnum].width/2, objkey.all[objnum].width/2)
			end
		end
	end
end